from setuptools import setup

setup(
    name='ACNLogger',    # This is the name of your PyPI-package.
    version='0.2.1',                          # Update the version number for new releases
	scripts=['ACNLogger']                  # The name of your scipt, and also the command you'll be using for calling it
)
